@@ -3,7 +3,7 @@
  * @brief Implements an LV2 plugin inheriting from MidiArp
  *
  *
- *      Copyright 2009 - 2023 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2024 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -53,7 +53,8 @@ MidiArpLV2::MidiArpLV2 (
         evTickQueue[l1] = 0;
     }
 
-    sendPatternFlag = false;
+    updatePattern(">>0");
+    sendPatternFlag = true;
     ui_up = false;
 
     bufPtr = 0;
